// Піни
const int soundSensorPin = A0; // Аналоговий вихід датчика звуку
const int redPin = 2;          // Червоний світлодіод
const int greenPin = 3;        // Зелений світлодіод
const int bluePin = 4;         // Синій світлодіод

// Змінні
int soundLevel = 0;                           // Теперешнє значення рівня звуку
int clapCount = 0;                            // К-сть хлопків
unsigned long lastClapTime = 0;               // Час останнього хлопка
const unsigned long maxClapInterval = 1500;   // Максимальное затримка між хлопками (мс)
bool colorChanged = false;                    // Прапор зміни кольору

void setup() {
  // Налаштування пінів
  pinMode(redPin, OUTPUT);
  pinMode(greenPin, OUTPUT);
  pinMode(bluePin, OUTPUT);

  // Ініциалізація
  digitalWrite(redPin, LOW);
  digitalWrite(greenPin, LOW);
  digitalWrite(bluePin, LOW);

  // Запуск Serial для моніторингу
  Serial.begin(9600);
}

void loop() {
  // Читання данних з датчика звуку
  soundLevel = analogRead(soundSensorPin);

  // Вивід рівня звуку в Serial Monitor
  Serial.println(soundLevel);

  // Якщо триманий рівень звуку з датчика > порогового рівня
  if (soundLevel > 350) {                     // Поріг чутливості (коригується відносно датчика)
    unsigned long currentTime = millis();
    if (currentTime - lastClapTime > 50) {    // Для більш точної роботи
      clapCount++;
      lastClapTime = currentTime;
    }
  }

  // Якщо час між хлопками > максимального часу очікування
  if (millis() - lastClapTime > maxClapInterval && clapCount > 0 && !colorChanged) {
    switch (clapCount) {
      case 1:
        setColor(true, false, false); // Червоний
        break;
      case 2:
        setColor(false, true, false); // Зелений
        break;
      case 3:
        setColor(false, false, true); // Синій
        break;
      default:
        setColor(false, false, false); // Вимкнути стрічку
        break;
    }
    colorChanged = true; // Колір змінився
    clapCount = 0;       // Обнулити рахунок хлопків
  }

  // Якщо хлопків немає, то обнуляємо прапор зміни кольору
  if (clapCount == 0) {
    colorChanged = false;
  }

  delay(50);
}

// Функція управління кольором стрічки
void setColor(bool red, bool green, bool blue) {
  digitalWrite(redPin, red ? HIGH : LOW);
  digitalWrite(greenPin, green ? HIGH : LOW);
  digitalWrite(bluePin, blue ? HIGH : LOW);
}